import { OnDestroy, OnInit } from '@angular/core';
import { LfI18n, LfRouter, LfStorage, PathBased } from '@lightweightform/core';
import { BsDatepickerConfig, BsDaterangepickerDirective } from 'ngx-bootstrap/datepicker';
import { InlineValue } from '../../abstract/inline-value';
import { BsLocaleChanger } from '../../services/bs-locale-changer.service';
/**
 * LF date-range component.
 */
export declare class DateRangeComponent extends InlineValue implements OnInit, OnDestroy {
    /**
     * Date-range picker directive.
     */
    _bsDateRangePicker: BsDaterangepickerDirective;
    private disposeBsConfigObserve;
    constructor(parentPathBasedComponent: PathBased | null, lfStorage: LfStorage, lfI18n: LfI18n, lfRouter: LfRouter | null, _bsLocaleChanger: BsLocaleChanger);
    /**
     * Format for a single date.
     */
    get dateFormat(): string;
    /**
     * Separator used between the dates in the date-range.
     */
    get separator(): string;
    /**
     * Placeholder of the `input` field.
     */
    get placeholder(): string;
    /**
     * Whether to show the "is required" icon on the component.
     */
    get showIsRequired(): boolean;
    /**
     * Minimum allowed date.
     */
    get minDate(): Date | undefined;
    /**
     * Maximum allowed date.
     */
    get maxDate(): Date | undefined;
    /**
     * Configuration to use by Bootstrap datepicker.
     */
    get bsConfig(): Partial<BsDatepickerConfig>;
    ngOnInit(): void;
    ngOnDestroy(): void;
    /**
     * Action to run whenever the date range is modified via the Bootstrap
     * datepicker UI.
     * @param dateRange Tuple representing the range.
     */
    _onDateRangePickerChange(dateRange: [Date, Date] | null): void;
    _onFocus(evt: FocusEvent): void;
    /**
     * Set touched when the date picker is hidden rather than on blur (it is
     * possible to change the value via the popup without actually focusing the
     * input; besides, otherwise the input may go invalid when the user selects
     * the first date of the range, but before the second).
     */
    _onDateRangePickerHidden(): void;
    protected validatePath(): void;
}
