import { OnDestroy, OnInit } from '@angular/core';
import { LfI18n, LfRouter, LfStorage, PathBased } from '@lightweightform/core';
import { BsDatepickerConfig, BsDatepickerDirective } from 'ngx-bootstrap/datepicker';
import { InlineValue } from '../../abstract/inline-value';
import { BsLocaleChanger } from '../../services/bs-locale-changer.service';
/**
 * LF date component.
 */
export declare class DateComponent extends InlineValue implements OnInit, OnDestroy {
    /**
     * Datepicker directive.
     */
    _bsDatePicker: BsDatepickerDirective;
    private disposeBsConfigObserve;
    constructor(parentPathBasedComponent: PathBased | null, lfStorage: LfStorage, lfI18n: LfI18n, lfRouter: LfRouter | null, _bsLocaleChanger: BsLocaleChanger);
    /**
     * Format of the date.
     */
    get dateFormat(): string;
    /**
     * Placeholder of the `input` field.
     */
    get placeholder(): string;
    /**
     * Whether to show the "is required" icon on the component.
     */
    get showIsRequired(): boolean;
    /**
     * Minimum allowed date.
     */
    get minDate(): Date | undefined;
    /**
     * Maximum allowed date.
     */
    get maxDate(): Date | undefined;
    /**
     * Config for the `BsDatepicker`.
     */
    get bsConfig(): Partial<BsDatepickerConfig>;
    ngOnInit(): void;
    ngOnDestroy(): void;
    /**
     * Action to run whenever the date `input` changes.
     * @param date Date to set.
     */
    _onDatePickerChange(date: Date | null): void;
    _onFocus(evt: FocusEvent): void;
    /**
     * Set touched when the date picker is hidden rather than on blur (it is
     * possible to change the value via the popup without actually focusing the
     * input).
     */
    _onDatePickerHidden(): void;
    protected validatePath(): void;
}
