import { LfI18n, LfStorage, PathBased } from '@lightweightform/core';
import { Value } from '../../abstract/value';
import { ActionsMenuAction } from '../actions-menu/actions-menu.component';
import { ModalComponent } from '../modal/modal.component';
/**
 * LF form component.
 */
export declare class FormComponent extends Value {
    /**
     * Modal used to show the form's help message.
     */
    _helpModal: ModalComponent;
    /**
     * Modal used to ask for confirmation when attempting to remove the form.
     */
    _removeModal: ModalComponent;
    constructor(parentPathBasedComponent: PathBased | null, lfStorage: LfStorage, lfI18n: LfI18n);
    /**
     * Text used for the "help" action.
     */
    get helpActionText(): string;
    /**
     * Text used for the "remove" action.
     */
    get removeActionText(): string;
    /**
     * Message displayed to the user to confirm removal of the form.
     */
    get ensureRemoveText(): string;
    /**
     * Text for the "cancel" button in the removal modal.
     */
    get cancelRemoveButtonText(): string;
    /**
     * Text for the "confirm" button in the removal modal.
     */
    get confirmRemoveButtonText(): string;
    /**
     * Whether this form can be removed (if it is `nullable` or its parent is a
     * list or map).
     */
    get isRemovable(): boolean;
    /**
     * Form-related actions shown on the top of the form.
     */
    get _formActions(): ActionsMenuAction[];
    /**
     * Removes this form by either setting it to `null` (when it is `nullable` or
     * removing it from its parent list or map).
     */
    remove(): void;
    _cancelRemove(): void;
    _confirmRemove(): Promise<void>;
    private showHelpModal;
    private showRemoveModal;
}
